@@ -96,8 +96,10 @@ class DLDSClient:
         if sys.platform in ['win32', 'cygwin'] and os.getlogin() == 'SYSTEM':
             # on windows in case the 'user' is SYSTEM, e.g. when started as a windows service
             dlds_dir = os.path.join(os.getenv('ALLUSERSPROFILE'), 'Data Spree', 'Deep Learning DS')
-        if not os.path.exists(dlds_dir):
+        try:
             os.makedirs(dlds_dir)
+        except FileExistsError:
+            pass
         return dlds_dir
 
     def download_dataset(self, directory, dataset_id, n_items=-1, accepted_status=None):
@@ -117,13 +119,20 @@ class DLDSClient:
             logger.error('Could not get list of dataset items for dataset with ID {}'.format(dataset_id))
 
         # create output directories
-        if not os.path.exists(directory):
+        try:
             os.makedirs(directory)
-        if not os.path.exists(os.path.join(directory, 'images')):
+        except FileExistsError:
+            pass
+        try:
             os.makedirs(os.path.join(directory, 'images'))
+        except FileExistsError:
+            pass
         image_dir = os.path.join(directory, 'images')
-        if not os.path.exists(os.path.join(directory, 'annotations')):
+        try:
             os.makedirs(os.path.join(directory, 'annotations'))
+        except FileExistsError:
+            pass
+
         annotation_dir = os.path.join(directory, 'annotations')
 
         if n_items != -1:
@@ -203,8 +212,10 @@ class DLDSClient:
 
         image_bytes = None
         if image_dir:
-            if not os.path.exists(image_dir):
+            try:
                 os.makedirs(image_dir)
+            except FileExistsError:
+                pass
             image_file_path = os.path.join(image_dir, item_name)
 
             if return_item:
@@ -218,8 +229,10 @@ class DLDSClient:
                     f.write(image_bytes)
 
         if annotation_dir:
-            if not os.path.exists(annotation_dir):
+            try:
                 os.makedirs(annotation_dir)
+            except FileExistsError:
+                pass
             # write annotations to file
             annotations = item_details['annotations']
             annotation_file_name = os.path.splitext(item_name)[0] + '.json'
@@ -961,6 +974,10 @@ class DLDSClient:
                         class_id = inverse_class_id_map[c]
                         class_confidences[class_id] = float(result['detection']['class_confidences'][j][c])
 
+                    orientation = 0
+                    if len(box) > 4:
+                        orientation = box[4]
+
                     detection_result.append({
                         'id': j,
                         'class_confidences': class_confidences,
@@ -968,7 +985,7 @@ class DLDSClient:
                         'y': box[1] / scale_y,
                         'width': box[2] / scale_x,
                         'height': box[3] / scale_y,
-                        'orientation': 0
+                        'orientation': orientation
                     })
 
             result_dict = {}
